@@ -13,6 +13,11 @@ from .RateLimitedSender import RateLimitedSender
 
 from typing import TypedDict
 
+# 自定义错误类型，继承自 Exception
+class NetWorkIdleTimeout(Exception):
+    """这是一个自定义错误类型"""
+    pass
+
 # 定义一个 TypedDict 来提供配置结构的类型提示
 
 class ZiNiao(TypedDict):
@@ -161,7 +166,6 @@ def remove_columns(matrix, indices):
     # 遍历每行，只保留不在indices中的列
     return [[row[i] for i in indices_to_keep] for row in matrix]
 
-
 def filter_columns(matrix, indices):
     """
     过滤二维列表，只保留指定索引的列
@@ -182,7 +186,6 @@ def filter_columns(matrix, indices):
     # 将过滤后的列转回二维列表
     return [list(row) for row in zip(*filtered_columns)]
 
-
 # # 示例使用
 # matrix = [
 #     [1, 2, 3, 4],
@@ -216,7 +219,6 @@ def add_column_to_2d_list(data, new_col, index=None):
         new_data.append(row)
     return new_data
 
-
 def add_prefixed_column(data, header, value):
     """
     给二维列表增加第一列，第一行为 header，后面为 value。
@@ -232,7 +234,6 @@ def add_prefixed_column(data, header, value):
     new_col = [header] + [value] * (len(data) - 1)
     return [[new_col[i]] + row for i, row in enumerate(data)]
 
-
 def add_suffixed_column(data, header, value):
     """
     给二维列表增加第一列，第一行为 header，后面为 value。
@@ -248,7 +249,6 @@ def add_suffixed_column(data, header, value):
     new_col = [header] + [value] * (len(data) - 1)
     return [row + [new_col[i]] for i, row in enumerate(data)]
 
-
 def merge_2d_lists_keep_first_header(data1, data2):
     """
     合并两个二维列表，只保留第一个列表的标题（即第一行）。
@@ -268,7 +268,6 @@ def merge_2d_lists_keep_first_header(data1, data2):
 
     return [header] + rows1 + rows2
 
-
 def insert_total_row(data, row_index=1, label="合计"):
     """
     在指定行插入一行，第一列为 label，其余为空字符串。
@@ -286,7 +285,6 @@ def insert_total_row(data, row_index=1, label="合计"):
 
     return data[:row_index] + [new_row] + data[row_index:]
 
-
 def insert_empty_column_after(data, col_index, new_header="单价成本"):
     """
     在二维列表中指定列的后面插入一个新列，标题为 new_header，其余内容为空字符串。
@@ -308,7 +306,6 @@ def insert_empty_column_after(data, col_index, new_header="单价成本"):
 
     return new_data
 
-
 def insert_empty_column_after_column_name(data, target_col_name, new_header="单价成本"):
     """
     在指定列名对应的列后面插入一个新列，标题为 new_header，其余行为空字符串。
@@ -334,4 +331,4 @@ def insert_empty_column_after_column_name(data, target_col_name, new_header="单
         row.insert(col_index + 1, insert_value)
         new_data.append(row)
 
-    return new_data
\ No newline at end of file
+    return new_data
